==> knative-annotations-4.0.0-sources.jar: io/dekorate/knative/config/GlobalAutoScalingFluent.java <==
package io.dekorate.knative.config;

import java.lang.Integer;
import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class GlobalAutoScalingFluent<A extends GlobalAutoScalingFluent<A>> extends BaseFluent<A>{
  public GlobalAutoScalingFluent() {
  }
  public GlobalAutoScalingFluent(GlobalAutoScaling instance) {
    instance = (instance != null ? instance : new GlobalAutoScaling());

    if (instance != null) {
      this.withAutoScalerClass(instance.getAutoScalerClass());
      this.withContainerConcurrency(instance.getContainerConcurrency());
      this.withTargetUtilizationPercentage(instance.getTargetUtilizationPercentage());
      this.withRequestsPerSecond(instance.getRequestsPerSecond());
    }
  }
  private AutoScalerClass autoScalerClass;
  private Integer containerConcurrency;
  private Integer targetUtilizationPercentage;
  private Integer requestsPerSecond;
  public AutoScalerClass getAutoScalerClass() {
    return this.autoScalerClass;
  }
  public A withAutoScalerClass(AutoScalerClass autoScalerClass) {
    this.autoScalerClass=autoScalerClass; return (A) this;
  }
  public boolean hasAutoScalerClass() {
    return this.autoScalerClass != null;
  }
  public Integer getContainerConcurrency() {
    return this.containerConcurrency;
  }
  public A withContainerConcurrency(Integer containerConcurrency) {
    this.containerConcurrency=containerConcurrency; return (A) this;
  }
  public boolean hasContainerConcurrency() {
    return this.containerConcurrency != null;
  }
  public Integer getTargetUtilizationPercentage() {
    return this.targetUtilizationPercentage;
  }
  public A withTargetUtilizationPercentage(Integer targetUtilizationPercentage) {
    this.targetUtilizationPercentage=targetUtilizationPercentage; return (A) this;
  }
  public boolean hasTargetUtilizationPercentage() {
    return this.targetUtilizationPercentage != null;
  }
  public Integer getRequestsPerSecond() {
    return this.requestsPerSecond;
  }
  public A withRequestsPerSecond(Integer requestsPerSecond) {
    this.requestsPerSecond=requestsPerSecond; return (A) this;
  }
  public boolean hasRequestsPerSecond() {
    return this.requestsPerSecond != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    GlobalAutoScalingFluent that = (GlobalAutoScalingFluent) o;
    if (!java.util.Objects.equals(autoScalerClass, that.autoScalerClass)) return false;

    if (!java.util.Objects.equals(containerConcurrency, that.containerConcurrency)) return false;

    if (!java.util.Objects.equals(targetUtilizationPercentage, that.targetUtilizationPercentage)) return false;

    if (!java.util.Objects.equals(requestsPerSecond, that.requestsPerSecond)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(autoScalerClass,  containerConcurrency,  targetUtilizationPercentage,  requestsPerSecond,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (autoScalerClass != null) { sb.append("autoScalerClass:"); sb.append(autoScalerClass + ","); }
    if (containerConcurrency != null) { sb.append("containerConcurrency:"); sb.append(containerConcurrency + ","); }
    if (targetUtilizationPercentage != null) { sb.append("targetUtilizationPercentage:"); sb.append(targetUtilizationPercentage + ","); }
    if (requestsPerSecond != null) { sb.append("requestsPerSecond:"); sb.append(requestsPerSecond); }
    sb.append("}");
    return sb.toString();
  }
  
}

==> knative-annotations-4.1.4-sources.jar: io/dekorate/knative/config/GlobalAutoScalingFluent.java <==
package io.dekorate.knative.config;

import java.lang.Integer;
import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class GlobalAutoScalingFluent<A extends GlobalAutoScalingFluent<A>> extends BaseFluent<A>{
  public GlobalAutoScalingFluent() {
  }
  
  public GlobalAutoScalingFluent(GlobalAutoScaling instance) {
    this.copyInstance(instance);
  }
  private AutoScalerClass autoScalerClass;
  private Integer containerConcurrency;
  private Integer targetUtilizationPercentage;
  private Integer requestsPerSecond;
  
  protected void copyInstance(GlobalAutoScaling instance) {
    instance = (instance != null ? instance : new GlobalAutoScaling());
    if (instance != null) {
          this.withAutoScalerClass(instance.getAutoScalerClass());
          this.withContainerConcurrency(instance.getContainerConcurrency());
          this.withTargetUtilizationPercentage(instance.getTargetUtilizationPercentage());
          this.withRequestsPerSecond(instance.getRequestsPerSecond());
        }
  }
  
  public AutoScalerClass getAutoScalerClass() {
    return this.autoScalerClass;
  }
  
  public A withAutoScalerClass(AutoScalerClass autoScalerClass) {
    this.autoScalerClass = autoScalerClass;
    return (A) this;
  }
  
  public boolean hasAutoScalerClass() {
    return this.autoScalerClass != null;
  }
  
  public Integer getContainerConcurrency() {
    return this.containerConcurrency;
  }
  
  public A withContainerConcurrency(Integer containerConcurrency) {
    this.containerConcurrency = containerConcurrency;
    return (A) this;
  }
  
  public boolean hasContainerConcurrency() {
    return this.containerConcurrency != null;
  }
  
  public Integer getTargetUtilizationPercentage() {
    return this.targetUtilizationPercentage;
  }
  
  public A withTargetUtilizationPercentage(Integer targetUtilizationPercentage) {
    this.targetUtilizationPercentage = targetUtilizationPercentage;
    return (A) this;
  }
  
  public boolean hasTargetUtilizationPercentage() {
    return this.targetUtilizationPercentage != null;
  }
  
  public Integer getRequestsPerSecond() {
    return this.requestsPerSecond;
  }
  
  public A withRequestsPerSecond(Integer requestsPerSecond) {
    this.requestsPerSecond = requestsPerSecond;
    return (A) this;
  }
  
  public boolean hasRequestsPerSecond() {
    return this.requestsPerSecond != null;
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    GlobalAutoScalingFluent that = (GlobalAutoScalingFluent) o;
    if (!java.util.Objects.equals(autoScalerClass, that.autoScalerClass)) return false;
    if (!java.util.Objects.equals(containerConcurrency, that.containerConcurrency)) return false;
    if (!java.util.Objects.equals(targetUtilizationPercentage, that.targetUtilizationPercentage)) return false;
    if (!java.util.Objects.equals(requestsPerSecond, that.requestsPerSecond)) return false;
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(autoScalerClass,  containerConcurrency,  targetUtilizationPercentage,  requestsPerSecond,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (autoScalerClass != null) { sb.append("autoScalerClass:"); sb.append(autoScalerClass + ","); }
    if (containerConcurrency != null) { sb.append("containerConcurrency:"); sb.append(containerConcurrency + ","); }
    if (targetUtilizationPercentage != null) { sb.append("targetUtilizationPercentage:"); sb.append(targetUtilizationPercentage + ","); }
    if (requestsPerSecond != null) { sb.append("requestsPerSecond:"); sb.append(requestsPerSecond); }
    sb.append("}");
    return sb.toString();
  }
  

}
